OfflinePushInfo class

Constructors

OfflinePushInfo({String? title, String? desc, String? ext, String? vendorParams, bool? disablePush, String? iOSSound, String? iOSImage, bool? ignoreIOSBadge, int? iOSPushType, String? iOSInterruptionLevel, bool? enableIOSBackgroundNotification, String? androidSound, String? androidOPPOChannelID, String? androidOPPOCategory, int? androidOPPONotifyLevel, String? androidVIVOCategory, int? androidVIVOClassification, String? androidFCMChannelID, String? androidFCMImage, String? androidXiaoMiChannelID, String? androidHuaWeiCategory, String? androidHuaWeiImage, String? androidHonorImage, String? androidHonorImportance, String? harmonyImage, String? harmonyCategory, bool? ignoreHarmonyBadge, int? androidMeizuNotifyType})
OfflinePushInfo.fromJson(Map json)
factory

Properties

androidFCMChannelID ↔ String?
getter/setter pair
androidFCMImage ↔ String?
getter/setter pair
androidHonorImage ↔ String?
getter/setter pair
androidHonorImportance ↔ String?
getter/setter pair
androidHuaWeiCategory ↔ String?
getter/setter pair
androidHuaWeiImage ↔ String?
getter/setter pair
androidMeizuNotifyType ↔ int?
getter/setter pair
androidOPPOCategory ↔ String?
getter/setter pair
androidOPPOChannelID ↔ String?
getter/setter pair
androidOPPONotifyLevel ↔ int?
getter/setter pair
androidSound ↔ String?
getter/setter pair
androidVIVOCategory ↔ String?
getter/setter pair
androidVIVOClassification ↔ int?
getter/setter pair
androidXiaoMiChannelID ↔ String?
getter/setter pair
desc ↔ String?
getter/setter pair
disablePush ↔ bool?
getter/setter pair
enableIOSBackgroundNotification ↔ bool?
getter/setter pair
ext ↔ String?
getter/setter pair
harmonyCategory ↔ String?
getter/setter pair
harmonyImage ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignoreHarmonyBadge ↔ bool?
getter/setter pair
ignoreIOSBadge ↔ bool?
getter/setter pair
iOSImage ↔ String?
getter/setter pair
iOSInterruptionLevel ↔ String?
getter/setter pair
iOSPushType ↔ int?
getter/setter pair
iOSSound ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
getter/setter pair
vendorParams ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited