V2TimApplicationProcessed class Models

V2TimApplicationProcessed

Constructors

V2TimApplicationProcessed({required String groupID, required V2TimGroupMemberInfo opUser, required bool isAgreeJoin, String? opReason})
V2TimApplicationProcessed.fromJson(Map json)

Properties

groupID ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAgreeJoin ↔ bool
getter/setter pair
opReason ↔ String?
getter/setter pair
opUser ↔ V2TimGroupMemberInfo
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited