V2TimConversationDraft class Models

V2TimConversationDraft

Constructors

V2TimConversationDraft({V2TimMessage? message, String? customData, int? editTime})
V2TimConversationDraft.fromJson(Map json)

Properties

customData ↔ String?
getter/setter pair
editTime ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ V2TimMessage?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited