V2TimGroupApplication class Models

V2TimGroupApplication

Constructors

V2TimGroupApplication({required String groupID, String? fromUser, String? fromUserNickName, String? fromUserFaceUrl, String? toUser, int? addTime, String? requestMsg, String? handledMsg, required int type, required int handleStatus, required int handleResult, dynamic authentication = ''})
V2TimGroupApplication.fromJson(Map json)

Properties

addTime ↔ int?
getter/setter pair
authentication → String
no setter
fromUser ↔ String?
getter/setter pair
fromUserFaceUrl ↔ String?
getter/setter pair
fromUserNickName ↔ String?
getter/setter pair
groupID ↔ String
getter/setter pair
handledMsg ↔ String?
getter/setter pair
handleResult ↔ int
getter/setter pair
handleStatus ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestMsg ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toUser ↔ String?
getter/setter pair
type ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited