V2TimGroupAttributeChanged class Models

V2TimGroupAttributeChanged

Constructors

V2TimGroupAttributeChanged({required String groupID, required Map<String, String> groupAttributeMap})
V2TimGroupAttributeChanged.fromJson(Map json)

Properties

groupAttributeMap ↔ Map<String, String>
getter/setter pair
groupID ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited