V2TimGroupCreateParam class Models

V2TimGroupCreateParam

Constructors

V2TimGroupCreateParam({required String groupName, required String groupType, String? groupID, String? notification, String? introduction, String? faceUrl, bool? isAllMuted, bool? isSupportTopic, GroupAddOptTypeEnum? addOpt, List<V2TimGroupMember>? memberList, GroupAddOptTypeEnum? approveOpt, bool? isEnablePermissionGroup, int? defaultPermissions, int? maxMemberCount})
V2TimGroupCreateParam.fromGroupInfo(V2TimGroupInfo groupInfo)

Properties

addOpt ↔ GroupAddOptTypeEnum?
getter/setter pair
approveOpt ↔ GroupAddOptTypeEnum?
getter/setter pair
defaultPermissions ↔ int?
getter/setter pair
faceUrl ↔ String?
getter/setter pair
groupID ↔ String?
getter/setter pair
groupName ↔ String
getter/setter pair
groupType ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
introduction ↔ String?
getter/setter pair
isAllMuted ↔ bool?
getter/setter pair
isEnablePermissionGroup ↔ bool?
getter/setter pair
isSupportTopic ↔ bool?
getter/setter pair
maxMemberCount ↔ int?
getter/setter pair
memberList ↔ List<V2TimGroupMember>?
getter/setter pair
notification ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited