V2TimMessageDownloadProgress class Models

V2TimMessageDownloadProgress

Constructors

V2TimMessageDownloadProgress({required bool isFinish, required bool isError, required String msgID, required int totalSize, required int currentSize, required int type, required bool isSnapshot, required String path, required int errorCode, required String errorDesc})
V2TimMessageDownloadProgress.fromJson(Map json)

Properties

currentSize ↔ int
getter/setter pair
errorCode ↔ int
getter/setter pair
errorDesc ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isError ↔ bool
该字段废弃
getter/setter pair
isFinish ↔ bool
getter/setter pair
isSnapshot ↔ bool
getter/setter pair
msgID ↔ String
getter/setter pair
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSize ↔ int
getter/setter pair
type ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited