V2TimMessageQuoteInfo class Models

V2TimMessageQuoteInfo

Constructors

V2TimMessageQuoteInfo({String? msgID, int? messageTime, int? messageSequence})
V2TimMessageQuoteInfo.fromJson(Map json)

Properties

hashCode int
The hash code for this object.
no setterinherited
messageSequence int?
被引用的消息 sequence
getter/setter pair
messageTime int?
被引用的消息时间
getter/setter pair
msgID String?
被引用的消息 ID
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toLogString() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited