V2TimStreamElem class Models

V2TimStreamElem

Inheritance

Constructors

V2TimStreamElem({String? streamID, String? markdown, String? data, bool? isStreamEnded})
V2TimStreamElem.fromJson(Map json)

Properties

data ↔ String?
getter/setter pair
elemType ↔ int?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isStreamEnded ↔ bool?
getter/setter pair
markdown ↔ String?
getter/setter pair
nextElem → dynamic
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamID ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setElemIndexInternal(int index) → void
inherited
setMessageInternal(V2TimMessage message) → void
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited