V2TimTopicInfo class Models

V2TimTopicInfo

Constructors

V2TimTopicInfo({String? topicID, String? topicName, String? topicFaceUrl, String? introduction, String? notification, bool? isAllMute, int? selfMuteTime, String? customString, String? draftText, int? unreadCount, V2TimMessage? lastMessage, int? messageReadSequence, List<V2TimGroupAtInfo>? groupAtInfoList, int? createTime, int? defaultPermissions, bool? isInheritMessageReceiveOptionFromCommunity})
V2TimTopicInfo.fromJson(Map json)

Properties

createTime ↔ int?
getter/setter pair
customString ↔ String?
getter/setter pair
defaultPermissions ↔ int?
getter/setter pair
draftText ↔ String?
getter/setter pair
groupAtInfoList ↔ List<V2TimGroupAtInfo>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
introduction ↔ String?
getter/setter pair
isAllMute ↔ bool?
getter/setter pair
isInheritMessageReceiveOptionFromCommunity ↔ bool?
getter/setter pair
lastMessage ↔ V2TimMessage?
getter/setter pair
messageReadSequence ↔ int?
getter/setter pair
notification ↔ String?
getter/setter pair
recvOpt ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfMuteTime ↔ int?
getter/setter pair
topicFaceUrl ↔ String?
getter/setter pair
topicID ↔ String?
getter/setter pair
topicName ↔ String?
getter/setter pair
unreadCount ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setInheritMessageReceiveOptionFromCommunity(bool isInherit) → Future<V2TimCallback>
设置登录用户在话题中的消息接收选项是否继承社群。 该功能仅增强版 SDK 8.1 及以上版本支持。 web版本不支持
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited