V2TimTopicInfoSetParam class Models

V2TimTopicInfoSetParam

Constructors

V2TimTopicInfoSetParam({required V2TimTopicInfo topicInfo})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topicInfo ↔ V2TimTopicInfo
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited