V2TimUserStatus class Models

V2TimUserStatus

Constructors

V2TimUserStatus({String? userID, int? statusType, String? customStatus, List<String>? onlineDevices})
V2TimUserStatus.fromJson(Map json)

Properties

customStatus ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onlineDevices ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusType ↔ int?
getter/setter pair
userID ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited