V2TimValueCallback<T> class Models

V2TimValueCallback

Constructors

V2TimValueCallback({required int code, required String desc, T? data})
V2TimValueCallback.fromBool(bool isSuccess, String desc)
V2TimValueCallback.fromJson(Map json)
V2TimValueCallback.fromObject(T result)

Properties

code ↔ int
getter/setter pair
data ↔ T?
getter/setter pair
desc ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited