NativeLibraryManager class

Constructors

NativeLibraryManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

bindings → NativeImsdkBindings
final
instance ↔ NativeLibraryManager
getter/setter pair

Static Methods

addTimApiValueCallback2Map(String userData, ApiCallback callback) → void
注册一个自定义的 ApiCallback 到 _apiCallbackMap。
addTimCallback2Map(String userData, Completer<V2TimCallback> completer) → void
注册一个标准的 V2TimCallback 回调到 _apiCallbackMap。
addTimValueCallback2Map<T>(String userData, Completer<V2TimValueCallback<T>> completer) → void
注册一个标准的 V2TimValueCallback 回调到 _apiCallbackMap。
registerPort() → void
removeTimCallbackFromMap(String userData) → void
从 _apiCallbackMap 移除指定 userData 的 closure。
setAdvancedMessageListener(V2TimAdvancedMsgListener listener) → void
setCommunityListener(V2TimCommunityListener listener) → void
setConversationListener(V2TimConversationListener listener) → void
setFriendshipListener(V2TimFriendshipListener listener) → void
setGroupListener(V2TimGroupListener listener) → void
setSdkListener(V2TimSDKListener listener, {bool enableLogCallback = false}) → void
setSignalingListener(V2TimSignalingListener listener) → void
unregisterPort() → void