Tools class

Constructors

Tools()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

freePointer(Pointer<NativeType> pointer) → void
freePointers(List<Pointer<NativeType>> pointers) → void
generateUserData(String apiName) → String
jsonList2Map<T>(List<Map<String, dynamic>> jsonList, String key, String value) → Map<String, T>
map2JsonList(Map<String, dynamic> originalMap, String key, String value) → List<Map<String, dynamic>>
pointerChar2String(Pointer<Char> data) → String
string2PointerChar(String data) → Pointer<Char>
string2PointerVoid(String data) → Pointer<Void>