V2TimGroupCreate class

Constructors

V2TimGroupCreate()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

convertGroupCustomInfoFromDartToWeb(Map<String, dynamic> customInfo) → List
convertGroupCustomInfoFromWebToDart(List customInfo) → Map
convertGroupResultFromWebToDart(Map<String, dynamic> params) → Map<String, dynamic>
formateGroupListResult(List resultFromJS) → List
formateParams(Map<String, dynamic> params) → Object