V2TIMMessage class

Constructors

V2TIMMessage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

convertGroupNoticeMessage(Map<String, dynamic> message) → Future<NoticeMessageListenner?>
convertGroupTipsMessage(Map<String, dynamic> message, {String groupID = ""}) → Future<V2TimGroupTipsElem?>
convertMessageFromWebToDart(dynamic jsMessage, {dynamic isFromDownloadMergerMessage = false}) → Future<Map<String, dynamic>>
getReciveMessageType(Map<String, dynamic> messageItem) → String